@@ -124,12 +124,11 @@ instance Yesod App where
     --     hamletToRepHtml $(hamletFile "templates/default-layout-wrapper.hamlet")
 
         pc <- widgetToPageContent $ do
-            $(widgetFile "normalize")
             addStylesheet $ StaticR css_bootstrap_min_css
              -- load these things early, in HEAD:
             toWidgetHead [hamlet|
-                          <script type="text/javascript" src="@{StaticR js_jquery_min_js}"></script>
-                          <script type="text/javascript" src="@{StaticR js_typeahead_bundle_min_js}"></script>
+                          <script type="text/javascript" src="@{StaticR js_jquery_min_js}">
+                          <script type="text/javascript" src="@{StaticR js_typeahead_bundle_min_js}">
                          |]
             addScript $ StaticR js_bootstrap_min_js
             -- addScript $ StaticR js_typeahead_bundle_min_js
@@ -216,8 +215,8 @@ nullviewdata = viewdataWithDateAndParams nulldate "" "" ""
 -- | Make a ViewData using the given date and request parameters, and defaults elsewhere.
 viewdataWithDateAndParams :: Day -> String -> String -> String -> ViewData
 viewdataWithDateAndParams d q a p =
-    let (querymatcher,queryopts) = parseQuery d q
-        (acctsmatcher,acctsopts) = parseQuery d a
+    let (querymatcher,queryopts) = parseQuery d (pack q)
+        (acctsmatcher,acctsopts) = parseQuery d (pack a)
     in VD {
            opts         = defwebopts
           ,j            = nulljournal
@@ -230,57 +229,62 @@ viewdataWithDateAndParams d q a p =
           ,am           = acctsmatcher
           ,aopts        = acctsopts
           ,showpostings = p == "1"
-          ,showsidebar  = False
+          ,showsidebar  = True
           }
 
 -- | Gather data used by handlers and templates in the current request.
 getViewData :: Handler ViewData
 getViewData = do
-  app        <- getYesod
-  let opts@WebOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} = appOpts app
-  (j, merr)  <- getCurrentJournal app copts{reportopts_=ropts{no_elide_=True}}
-  lastmsg    <- getLastMessage
-  let msg = maybe lastmsg (Just . toHtml) merr
-  Just here  <- getCurrentRoute
-  today      <- liftIO getCurrentDay
-  q          <- getParameterOrNull "q"
-  a          <- getParameterOrNull "a"
-  p          <- getParameterOrNull "p"
+  mhere      <- getCurrentRoute
+  case mhere of
+    Nothing -> return nullviewdata
+    Just here -> do
+      app        <- getYesod
+      let opts@WebOpts{cliopts_=copts@CliOpts{reportopts_=ropts}} = appOpts app
+      today      <- liftIO getCurrentDay
+      (j, merr)  <- getCurrentJournal app copts{reportopts_=ropts{no_elide_=True}} today
+      lastmsg    <- getLastMessage
+      let msg = maybe lastmsg (Just . toHtml) merr
+      q          <- getParameterOrNull "q"
+      a          <- getParameterOrNull "a"
+      p          <- getParameterOrNull "p"
+      -- sidebar visibility: show it, unless there is a showsidebar cookie
+      -- set to "0", or a ?sidebar=0 query parameter.
+      msidebarparam <- lookupGetParam "sidebar"
+      msidebarcookie <- reqCookies <$> getRequest >>= return . lookup "showsidebar"
+      let showsidebar = maybe (msidebarcookie /= Just "0") (/="0") msidebarparam
 
-  -- a "sidebar" query parameter overrides the "showsidebar" cookie
-  sidebarparam <- lookupGetParam (pack "sidebar")
-  cookies <- reqCookies <$> getRequest
-  let sidebarcookie = lookup "showsidebar" cookies
-  let showsidebar = maybe (sidebarcookie == Just "1") (=="1") sidebarparam
+      return (viewdataWithDateAndParams today q a p){
+                   opts=opts
+                  ,msg=msg
+                  ,here=here
+                  ,today=today
+                  ,j=j
+                  ,showsidebar=showsidebar
+                  }
+        where
+          -- | Update our copy of the journal if the file changed. If there is an
+          -- error while reloading, keep the old one and return the error, and set a
+          -- ui message.
+          getCurrentJournal :: App -> CliOpts -> Day -> Handler (Journal, Maybe String)
+          getCurrentJournal app opts d = do
+            -- XXX put this inside atomicModifyIORef' for thread safety
+            j <- liftIO $ readIORef $ appJournal app
+            (ej, changed) <- liftIO $ journalReloadIfChanged opts d j
+            -- re-apply any initial filter specified at startup
+            let initq = queryFromOpts d $ reportopts_ opts
+                ej' = filterJournalTransactions initq <$> ej
+            if not changed
+             then return (j,Nothing)
+             else case ej' of
+                    Right j' -> do liftIO $ writeIORef (appJournal app) j'
+                                   return (j',Nothing)
+                    Left e   -> do setMessage $ "error while reading" {- ++ ": " ++ e-}
+                                   return (j, Just e)
 
-  return (viewdataWithDateAndParams today q a p){
-               opts=opts
-              ,msg=msg
-              ,here=here
-              ,today=today
-              ,j=j
-              ,showsidebar=showsidebar
-              }
-    where
-      -- | Update our copy of the journal if the file changed. If there is an
-      -- error while reloading, keep the old one and return the error, and set a
-      -- ui message.
-      getCurrentJournal :: App -> CliOpts -> Handler (Journal, Maybe String)
-      getCurrentJournal app opts = do
-        -- XXX put this inside atomicModifyIORef' for thread safety
-        j <- liftIO $ readIORef $ appJournal app
-        (jE, changed) <- liftIO $ journalReloadIfChanged opts j
-        if not changed
-         then return (j,Nothing)
-         else case jE of
-                Right j' -> do liftIO $ writeIORef (appJournal app) j'
-                               return (j',Nothing)
-                Left e   -> do setMessage $ "error while reading" {- ++ ": " ++ e-}
-                               return (j, Just e)
-
-      -- | Get the named request parameter, or the empty string if not present.
-      getParameterOrNull :: String -> Handler String
-      getParameterOrNull p = unpack `fmap` fromMaybe "" <$> lookupGetParam (pack p)
+          -- | Get the named request parameter, or the empty string if not present.
+          getParameterOrNull :: String -> Handler String
+          getParameterOrNull p = unpack `fmap` fromMaybe "" <$> lookupGetParam (pack p)
 
 -- | Get the message that was set by the last request, in a
 -- referentially transparent manner (allowing multiple reads).
@@ -333,24 +337,31 @@ addform _ vd@VD{..} = [hamlet|
 
   });
 
-<form#addform method=POST style="position:relative;">
-  <table.form style="width:100%; white-space:nowrap;">
-   <tr>
-    <td colspan=4>
-     <table style="width:100%;">
-      <tr#descriptionrow>
-       <td>
-        <input #date        .typeahead .form-control .input-lg type=text size=15 name=date placeholder="Date" value=#{defdate}>
-       <td>
-        <input #description .typeahead .form-control .input-lg type=text size=40 name=description placeholder="Description">
-   $forall n <- postingnums
+<form#addform method=POST .form>
+ <div .form-group>
+  <div .row>
+   <div .col-md-2 .col-xs-6 .col-sm-6>
+    <input #date .typeahead .form-control .input-lg type=text size=15 name=date placeholder="Date" value="#{defdate}">
+   <div .col-md-10 .col-xs-6 .col-sm-6>
+    <input #description .typeahead .form-control .input-lg type=text size=40 name=description placeholder="Description">
+ <div .account-postings>
+  $forall n <- postingnums
     ^{postingfields vd n}
-  <span style="padding-left:2em;">
-   <span .small>
-     Tab in last field for <a .small href="#" onclick="addformAddPosting(); return false;">more</a> (or ctrl +, ctrl -)
+ <div .col-md-8 .col-xs-8 .col-sm-8>
+ <div .col-md-4 .col-xs-4 .col-sm-4>
+  <button type=submit .btn .btn-default .btn-lg name=submit>add
+ $if length filepaths > 1
+  <br>
+  <span class="input-lg">to:
+   ^{journalselect filepaths}
+ <span style="padding-left:2em;">
+  <span .small>
+    Enter a value in the last field for
+    <a href="#" onclick="addformAddPosting(); return false;">more
+    (or ctrl +, ctrl -)
 |]
  where
-  defdate = "today" :: String
+  defdate = "" :: String -- #322 don't set a default, typeahead(?) clears it on tab. See also hledger.js
   dates = ["today","yesterday","tomorrow"] :: [String]
   descriptions = sort $ nub $ map tdescription $ jtxns j
   accts = sort $ journalAccountNamesUsed j
@@ -358,36 +369,21 @@ addform _ vd@VD{..} = [hamlet|
   listToJsonValueObjArrayStr as  = preEscapedString $ escapeJSSpecialChars $ encode $ JSArray $ map (\a -> JSObject $ toJSObject [("value", showJSON a)]) as
   numpostings = 4
   postingnums = [1..numpostings]
+  filepaths = map fst $ jfiles j
   postingfields :: ViewData -> Int -> HtmlUrl AppRoute
   postingfields _ n = [hamlet|
-<tr .posting>
- <td style="padding-left:2em;">
-  <input ##{acctvar} .account-input .typeahead .form-control .input-lg style="width:100%;" type=text name=#{acctvar} placeholder="#{acctph}">
- ^{amtfieldorsubmitbtn}
+<div .form-group .row .account-group ##{grpvar}>
+ <div .col-md-8 .col-xs-8 .col-sm-8>
+  <input ##{acctvar} .account-input .typeahead .form-control .input-lg type=text name=#{acctvar} placeholder="#{acctph}">
+ <div .col-md-4 .col-xs-4 .col-sm-4>
+  <input ##{amtvar} .amount-input .form-control .input-lg type=text name=#{amtvar} placeholder="#{amtph}">
 |]
    where
-    islast = n == numpostings
     acctvar = "account" ++ show n
     acctph = "Account " ++ show n
-    amtfieldorsubmitbtn
-       | not islast = [hamlet|
-          <td>
-           <input ##{amtvar} .amount-input .form-control .input-lg type=text size=10 name=#{amtvar} placeholder="#{amtph}">
-         |]
-       | otherwise = [hamlet|
-          <td #addbtncell style="text-align:right;">
-           <button type=submit .btn .btn-lg name=submit>add
-           $if length filepaths > 1
-            <br>
-            <span class="input-lg">to:
-            ^{journalselect filepaths}
-         |]
-       where
-        amtvar = "amount" ++ show n
-        amtph = "Amount " ++ show n
-        filepaths = map fst $ files j
-
-           -- <button .btn style="font-size:18px;" type=submit title="Add this transaction">Add
+    amtvar = "amount" ++ show n
+    amtph = "Amount " ++ show n
+    grpvar = "grp" ++ show n
 
 journalselect :: [FilePath] -> HtmlUrl AppRoute
 journalselect journalfilepaths = [hamlet|
