@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -- | Web handler utilities. More of these are in Foundation.hs, where
 -- they can be used in the default template.
 
@@ -7,8 +8,9 @@ import Prelude
 import Data.Time.Calendar
 import Data.Time.Clock
 import Data.Time.Format
+#if !(MIN_VERSION_time(1,5,0))
 import System.Locale (defaultTimeLocale)
-
+#endif
 
 numbered :: [a] -> [(Int,a)]
 numbered = zip [1..]
