@@ -3,19 +3,19 @@ Re-export the modules of the hledger-web program.
 -}
 
 module Hledger.Web (
-                     module Hledger.Web.Options,
+                     module Hledger.Web.WebOptions,
                      module Hledger.Web.Main,
                      tests_Hledger_Web
               )
 where
 import Test.HUnit
 
-import Hledger.Web.Options
+import Hledger.Web.WebOptions
 import Hledger.Web.Main
 
 tests_Hledger_Web :: Test
 tests_Hledger_Web = TestList
  [
- --  tests_Hledger_Web_Options
+ --  tests_Hledger_Web_WebOptions
  -- ,tests_Hledger_Web_Main
  ]
