@@ -5,6 +5,12 @@
 
 $(document).ready(function() {
 
+  // ensure add form always focusses its first field
+  $('#addmodal')
+    .on('shown.bs.modal', function (e) {
+      addformFocus();
+    })
+
   // show add form if ?add=1
   if ($.url.param('add')) { addformShow(true); }
 
@@ -24,8 +30,20 @@ $(document).ready(function() {
   $('body, #addform input, #addform select').bind('keydown', 'ctrl+shift+=', addformAddPosting);
   $('body, #addform input, #addform select').bind('keydown', 'ctrl+=',       addformAddPosting);
   $('body, #addform input, #addform select').bind('keydown', 'ctrl+-',       addformDeletePosting);
-  $('#addform tr.posting:last > td:first input').bind('keydown', 'tab', addformAddPostingWithTab);
+  $('.amount-input:last').keypress(addformAddPosting);
 
+
+  // highlight the entry from the url hash
+  if (window.location.hash && $(window.location.hash)[0]) {
+    $(window.location.hash).addClass('highlighted');
+  }
+  $(window).on('hashchange', function(event) {
+    $('.highlighted').removeClass('highlighted');
+    $(window.location.hash).addClass('highlighted');
+  });
+  $('[data-toggle="offcanvas"]').click(function () {
+      $('.row-offcanvas').toggleClass('active');
+  });
 });
 
 //----------------------------------------------------------------------
@@ -36,58 +54,39 @@ function registerChart($container, series) {
   return $container.plot(
     series,
     { /* general chart options */
-      // series: {
-      // },
-      // yaxis: {
-      //   /* ticks: 6, */
-      // },
       xaxis: {
         mode: "time",
         timeformat: "%Y/%m/%d"
-        /* ticks: 6, */
+      },
+      legend: {
+        position: 'sw'
       },
       grid: {
         markings:
          function (axes) {
           var now = Date.now();
           var markings = [
-            // {
-            //   xaxis: { to: now },        // past
-            //   yaxis: { from: 0, to: 0 }, // =0
-            //  color: '#d88',
-            //  lineWidth:1
-            // },
             {
               xaxis: { to: now }, // past
               yaxis: { to: 0 },   // <0
               color: '#ffdddd',
             },
-
-            // {
-            //   xaxis: { from: now, to: now }, // now
-            //  color: '#bbb',
-            // },
-
             {
               xaxis: { from: now }, // future
               yaxis: { from: 0 },   // >0
-              // color: '#dddddd',
               color: '#e0e0e0',
             },
             {
               xaxis: { from: now }, // future
               yaxis: { to: 0 },     // <0
-              // color: '#ddbbbb',
               color: '#e8c8c8',
             },
             {
-              // xaxis: { from: now },      // future
               yaxis: { from: 0, to: 0 }, // =0
               color: '#bb0000',
               lineWidth:1
             },
           ];
-          // console.log(markings);
           return markings;
         },
         hoverable: true,
@@ -113,13 +112,14 @@ function registerChart($container, series) {
 
 function registerChartClick(ev, pos, item) {
   if (item) {
-    var date = $.plot.dateGenerator(item.datapoint[0], {});
-    var dateid = $.plot.formatDate(date, '%Y-%m-%d');
-    $target = $('#'+dateid);
-    if ($target.length)
+    targetselector = '#'+item.series.data[item.dataIndex][5];
+    $target = $(targetselector);
+    if ($target.length) {
+      window.location.hash = targetselector;
       $('html, body').animate({
         scrollTop: $target.offset().top
       }, 1000);
+    }
   }
 }
 
@@ -129,11 +129,7 @@ function registerChartClick(ev, pos, item) {
 function addformShow(showmsg) {
   showmsg = typeof showmsg !== 'undefined' ? showmsg : false;
   addformReset(showmsg);
-  $('#addmodal')
-    .on('shown.bs.modal', function (e) {
-      addformFocus();
-    })
-    .modal('show');
+  $('#addmodal').modal('show');
 }
 
 // Make sure the add form is empty and clean for display.
@@ -145,7 +141,7 @@ function addformReset(showmsg) {
     // reset typehead state (though not fetched completions)
     $('.typeahead').typeahead('val', '');
     $('.tt-dropdown-menu').hide();
-    $('input#date').val('today');
+    $('input#date').val(''); // #322 don't set a default, typeahead(?) clears it on tab. See also Foundation.hs
   }
 }
 
@@ -163,44 +159,21 @@ function focus($el) {
 
 // Insert another posting row in the add form.
 function addformAddPosting() {
+  $('.amount-input:last').off('keypress');
   // do nothing if it's not currently visible
   if (!$('#addform').is(':visible')) return;
   // save a copy of last row
-  var lastrow = $('#addform tr.posting:last').clone();
+  var lastrow = $('#addform .form-group:last').clone();
 
   // replace the submit button with an amount field, clear and renumber it, add the keybindings
-  $('#addform tr.posting:last > td:last')
-    .html( $('#addform tr.posting:first > td:last').html() );
-  var num = $('#addform tr.posting').length;
-  $('#addform tr.posting:last > td:last input:last') // input:last here and elsewhere is to avoid autocomplete's extra input
-    .val('')
-    .prop('id','amount'+num)
-    .prop('name','amount'+num)
-    .prop('placeholder','Amount '+num)
-    .bind('keydown', 'ctrl+shift+=', addformAddPosting)
-    .bind('keydown', 'ctrl+=', addformAddPosting)
-    .bind('keydown', 'ctrl+-', addformDeletePosting);
-
-  // set up the new last row's account field.
-  // First typehead, it's hard to enable on new DOM elements
-  var $acctinput = lastrow.find('.account-input:last');
-  // XXX nothing works
-  // $acctinput.typeahead('destroy'); //,'NoCached');
-  // lastrow.on("DOMNodeInserted", function () {
-  //   //$(this).find(".typeahead").typeahead();
-  //   console.log('DOMNodeInserted');
-  //  // infinite loop
-  //  console.log($(this).find('.typeahead'));
-  //   //enableTypeahead($(this).find('.typeahead'), accountsSuggester);
-  // });
-  // setTimeout(function (){
-  //   $('#addform tr.posting:last input.account-input').typeahead('destroy');
-  //   enableTypeahead($('#addform tr.posting:last input.account-input:last'), accountsSuggester);
-  // }, 1000);
+  var num = $('#addform .account-group').length;
 
   // insert the new last row
-  $('#addform > table > tbody').append(lastrow);
+  $('#addform .account-postings').append(lastrow);
+  // TODO: Enable typehead on dynamically created inputs
 
+  var $acctinput = $('.account-input:last');
+  var $amntinput = $('.amount-input:last');
   // clear and renumber the field, add keybindings
   $acctinput
     .val('')
@@ -211,77 +184,47 @@ function addformAddPosting() {
   $acctinput
     .bind('keydown', 'ctrl+shift+=', addformAddPosting)
     .bind('keydown', 'ctrl+=', addformAddPosting)
-    .bind('keydown', 'ctrl+-', addformDeletePosting)
-    .bind('keydown', 'tab', addformAddPostingWithTab);
-}
+    .bind('keydown', 'ctrl+-', addformDeletePosting);
+
+  $amntinput
+    .val('')
+    .prop('id','amount'+(num+1))
+    .prop('name','amount'+(num+1))
+    .prop('placeholder','Amount '+(num+1))
+    .keypress(addformAddPosting);
+
+  $acctinput
+    .bind('keydown', 'ctrl+shift+=', addformAddPosting)
+    .bind('keydown', 'ctrl+=', addformAddPosting)
+    .bind('keydown', 'ctrl+-', addformDeletePosting);
 
-// Insert another posting row by tabbing within the last field, also advancing the focus.
-function addformAddPostingWithTab(ev) {
-  // do nothing if called from a non-last row (don't know how to remove keybindings)
-  if ($(ev.target).is('#addform input.account-input:last')) {
-    addformAddPosting();
-    focus($('#addform input.amount-input:last')); // help FF
-    return false;
-  }
-  else
-    return true;
 }
 
 // Remove the add form's last posting row, if empty, keeping at least two.
 function addformDeletePosting() {
-  var num = $('#addform tr.posting').length;
-  if (num <= 2
-      || $('#addform tr.posting:last > td:first input:last').val() != ''
-     ) return;
-  // copy submit button
-  var btn = $('#addform tr.posting:last > td:last').html();
+  var num = $('#addform .account-group').length;
+  if (num <= 2) return;
   // remember if the last row's field or button had focus
   var focuslost =
-    $('#addform tr.posting:last > td:first input:last').is(':focus')
-    || $('#addform tr.posting:last button').is(':focus');
+    $('.account-input:last').is(':focus')
+    || $('.amount-input:last').is(':focus');
   // delete last row
-  $('#addform tr.posting:last').remove();
-  // remember if the last amount field had focus
-  focuslost = focuslost || 
-    $('#addform tr.posting:last > td:last input:last').is(':focus');
-  // replace new last row's amount field with the button
-  $('#addform tr.posting:last > td:last').css('text-align','right').html(btn);
-  // if deleted row had focus, focus the new last row
-  if (focuslost) $('#addform tr.posting:last > td:first input:last').focus();
+  $('#addform .account-group:last').remove();
+  if(focuslost){
+    focus($('account-input:last'));
+  }
+  // Rebind keypress
+  $('.amount-input:last').keypress(addformAddPosting);
 }
 
 //----------------------------------------------------------------------
 // SIDEBAR
 
 function sidebarToggle() {
-  //console.log('sidebarToggle');
-  var visible = $('#sidebar').is(':visible');
-  //console.log('sidebar visibility was',visible);
-  // if opening sidebar, start an ajax fetch of its content
-  if (!visible) {
-    //console.log('getting sidebar content');
-    $.get("sidebar"
-         ,null
-         ,function(data) {
-            //console.log( "success" );
-            $("#sidebar-body" ).html(data);
-          })
-          .done(function() {
-            //console.log( "success 2" );
-          })
-          .fail(function() {
-            //console.log( "error" );
-          });
-  }
-  // localStorage.setItem('sidebarVisible', !visible);
-  // set a cookie to communicate the new sidebar state to the server
-  $.cookie('showsidebar', visible ? '0' : '1');
-  // horizontally slide the sidebar in or out
-  // how to make it smooth, without delayed content pop-in ?
-  //$('#sidebar').animate({'width': 'toggle'});
-  //$('#sidebar').animate({'width': visible ? 'hide' : '+=20m'});
-  //$('#sidebar-spacer').width(200);
-  $('#sidebar').animate({'width': visible ? 'hide' : 'show'});
+  $('#sidebar-menu').toggleClass('col-md-4 col-sm-4 col-any-0');
+  $('#main-content').toggleClass('col-md-8 col-sm-8 col-md-12 col-sm-12');
+  $('#spacer').toggleClass('col-md-4 col-sm-4 col-any-0');
+  $.cookie('showsidebar', $('#sidebar-menu').hasClass('col-any-0') ? '0' : '1');
 }
 
 //----------------------------------------------------------------------
